@@ -157,19 +157,19 @@ namespace Banshee.Base
                 new ActionEntry("WikiGuideAction", Stock.Help,
                     Catalog.GetString("Banshee User Guide (Wiki)"), null,
                     Catalog.GetString("Learn about how to use Banshee"), delegate {
-                        Gnome.Url.Show("http://banshee-project.org/Guide");
+                        Banshee.Web.Browser.Open("http://banshee-project.org/Guide");
                     }),
                     
                 new ActionEntry("WikiAction", null,
                     Catalog.GetString("Banshee Home Page"), null,
                     Catalog.GetString("Visit the Banshee Home Page"), delegate {
-                        Gnome.Url.Show("http://banshee-project.org/");
+                        Banshee.Web.Browser.Open("http://banshee-project.org/");
                     }),
                     
                 new ActionEntry("WikiDeveloperAction", null,
                     Catalog.GetString("Get Involved"), null,
                     Catalog.GetString("Become a contributor to Banshee"), delegate {
-                        Gnome.Url.Show("http://banshee-project.org/Developers");
+                        Banshee.Web.Browser.Open("http://banshee-project.org/Developers");
                     }),
                     
                 new ActionEntry("AboutAction", "gtk-about", null),
