@@ -35,6 +35,7 @@ using Mono.Unix;
 
 using Banshee.Widgets;
 using Banshee.Base;
+using Banshee.AudioProfiles;
 
 namespace Banshee.Base
 {
@@ -227,13 +228,47 @@ namespace Banshee.Base
         
         private uint timeout_id; 
         private int current = 1;
-        private PipelineProfile profile;
+        private Profile profile;
         
         public event HaveTrackInfoHandler HaveTrackInfo;
         public event EventHandler Finished;
         
         private ActiveUserEvent user_event;
         
+        [DllImport("libc")]
+        private static extern int ioctl(int device, IoctlOperation request, bool lockdoor); 
+
+        private enum IoctlOperation {
+            LockDoor = 0x5329
+        }
+        
+        private static bool LockDrive(string device, bool lockdoor)
+        {
+            using(UnixStream stream = (new UnixFileInfo(device)).Open( 
+                Mono.Unix.Native.OpenFlags.O_RDONLY | 
+                Mono.Unix.Native.OpenFlags.O_NONBLOCK)) {
+                return ioctl(stream.Handle, IoctlOperation.LockDoor, lockdoor) == 0;
+            }
+        }
+        
+        private void LockDrive()
+        {
+            lock(this) {
+                if(!LockDrive(device, true)) {
+                    LogCore.Instance.PushWarning("Could not lock CD-ROM drive", device, false);
+                }
+            }
+        }
+        
+        private void UnlockDrive()
+        {
+            lock(this) {
+                if(!LockDrive(device, false)) {
+                    LogCore.Instance.PushWarning("Could not unlock CD-ROM drive", device, false);
+                }
+            }
+        }
+        
         public AudioCdRipper()
         {
             user_event = new ActiveUserEvent(Catalog.GetString("Importing CD"));
@@ -269,13 +304,20 @@ namespace Banshee.Base
             user_event.Header = Catalog.GetString("Importing Audio CD");
             user_event.Message = Catalog.GetString("Initializing Drive");
         
-            profile = PipelineProfile.GetConfiguredProfile("Ripping");
+            profile = Globals.AudioProfileManager.GetConfiguredActiveProfile("cd-importing", 
+                new string [] { "audio/ogg", "audio/mp3", "audio/wav" });
             
             try {
-                string encodePipeline = profile.Pipeline;
+                if(profile == null) {
+                    throw new ApplicationException(Catalog.GetString("No encoder was found on your system."));
+                }
+            
+                string encodePipeline = profile.Pipeline.GetProcessById("gstreamer");
         
                 LogCore.Instance.PushDebug("Ripping CD and Encoding with Pipeline", encodePipeline);
             
+                LockDrive();
+            
                 ripper = new AudioCdTrackRipper(device, 0, encodePipeline);
                 ripper.Progress += OnRipperProgress;
                 ripper.TrackFinished += OnTrackRipped;
@@ -286,11 +328,19 @@ namespace Banshee.Base
                 total_tracks = tracks.Count;
                 
                 RipNextTrack();
-            } catch(PipelineProfileException e) {
+            } catch(Exception e) {
                 LogCore.Instance.PushError(Catalog.GetString("Cannot Import CD"), e.Message);
+                user_event.Dispose();
+                OnFinished();
             }
         }
         
+        public void Cancel()
+        {
+            user_event.Dispose();
+            OnFinished();
+        }
+        
         private void RipNextTrack()
         {
             if(tracks.Count <= 0) {
@@ -303,7 +353,7 @@ namespace Banshee.Base
             status = String.Format("{0} - {1}", track.Artist, track.Title);
             user_event.Message = status;
 
-            SafeUri uri = new SafeUri(FileNamePattern.BuildFull(track, profile.Extension));
+            SafeUri uri = new SafeUri(FileNamePattern.BuildFull(track, profile.OutputFileExtension));
 
             ripper.RipTrack(track, track.TrackIndex, uri);
         }
@@ -356,6 +406,7 @@ namespace Banshee.Base
         
         private void OnFinished()
         {
+            UnlockDrive();
             EventHandler handler = Finished;
             if(handler != null) {
                 handler(this, new EventArgs());
