@@ -31,6 +31,8 @@ using System.IO;
 using GConf;
 using Mono.Unix;
 
+using Banshee.AudioProfiles;
+
 namespace Banshee.Base
 {
     public delegate bool ShutdownRequestHandler();
@@ -47,6 +49,7 @@ namespace Banshee.Base
         private static DBusRemote dbus_remote;
         private static DBusPlayer dbus_player;
         private static Banshee.Gui.UIManager ui_manager;
+        private static ProfileManager audio_profile_manager;
         private static ComponentInitializer startup = new ComponentInitializer();
         
         public static event ShutdownRequestHandler ShutdownRequested;
@@ -66,6 +69,11 @@ namespace Banshee.Base
                 System.Environment.Exit(1);
                 return;
             }
+
+            // override the browser URI launch hook in Last.FM and Banshee.Widgets.LinkLabel
+            Last.FM.Browser.Open = new Last.FM.UriOpenHandler(Banshee.Web.Browser.Open);
+            Banshee.Widgets.LinkLabel.DefaultOpen = 
+                new Banshee.Widgets.LinkLabel.UriOpenHandler(Banshee.Web.Browser.Open);
                         
             startup.Register(Catalog.GetString("Starting background tasks"), delegate {
                 try {
@@ -75,7 +83,11 @@ namespace Banshee.Base
                 } catch {
                 }
             });
-            
+
+            startup.Register(Catalog.GetString("Starting background tasks"), true,
+                Catalog.GetString("Device support will be disabled for this instance (no HAL)"),
+                HalCore.Initialize);
+                
             startup.Register(Catalog.GetString("Starting background tasks"), delegate { gconf_client = new GConf.Client(); });
             startup.Register(Catalog.GetString("Detecting network settings"), delegate { network_detect = NetworkDetect.Instance; });
             startup.Register(Catalog.GetString("Creating action manager"), delegate { action_manager = new ActionManager(); });
@@ -84,8 +96,23 @@ namespace Banshee.Base
                 library.ReloadLibrary();
             });
             
-            startup.Register(Catalog.GetString("Initializing player engine"), Banshee.Gstreamer.Utilities.Initialize);
-            startup.Register(Catalog.GetString("Initializing player engine"), PlayerEngineCore.Initialize);
+            startup.Register(Catalog.GetString("Initializing audio"), Banshee.Gstreamer.Utilities.Initialize);
+            
+            startup.Register(Catalog.GetString("Initializing audio"), delegate {
+                string system_path = Path.Combine(Banshee.Base.Paths.SystemApplicationData, "audio-profiles.xml");
+                string user_path = Path.Combine(Banshee.Base.Paths.ApplicationData, "audio-profiles.xml");
+            
+                if(File.Exists(user_path)) {
+                    audio_profile_manager = new ProfileManager(user_path);
+                } else {
+                    audio_profile_manager = new ProfileManager(system_path);
+                }
+                    
+                audio_profile_manager.TestProfile += OnTestAudioProfile;
+                audio_profile_manager.TestAll();
+            });
+            
+            startup.Register(Catalog.GetString("Initializing audio"), PlayerEngineCore.Initialize);
             
             startup.Register(Catalog.GetString("Initializing audio CD support"), true, 
                 Catalog.GetString("Audio CD support will be disabled for this instance"), delegate { audio_cd_core = new AudioCdCore(); });
@@ -137,12 +164,17 @@ namespace Banshee.Base
             return true;
         }
         
+        private static void OnTestAudioProfile(object o, TestProfileArgs args)
+        {
+            string pipeline = args.Profile.Pipeline.GetProcessByIdOrDefault("gstreamer");
+            args.ProfileAvailable = Banshee.Gstreamer.Utilities.TestPipeline(pipeline);
+        }
+        
         private static void Dispose()
         {
             dbus_remote.UnregisterObject(dbus_player);
             Banshee.Kernel.Scheduler.Dispose();
             Banshee.Plugins.PluginCore.Dispose();
-            network_detect.Dispose();
             library.Db.Dispose();
             Banshee.Dap.DapCore.Dispose();
             HalCore.Dispose();
@@ -193,6 +225,10 @@ namespace Banshee.Base
         public static Banshee.Gui.UIManager UIManager {
             get { return ui_manager; }
         }
+        
+        public static ProfileManager AudioProfileManager {
+            get { return audio_profile_manager; }
+        }
     }
     
     public static class InterfaceElements
