@@ -28,6 +28,7 @@
  
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using System.Data;
 using System.IO;
 using Mono.Unix;
@@ -54,9 +55,8 @@ namespace Banshee.Base
     public class Library
     {
         public BansheeDatabase Db;
-        public Hashtable Tracks = new Hashtable();
-        public Hashtable TracksFnKeyed = new Hashtable();
-        public Hashtable Playlists = new Hashtable();
+        public Dictionary<int, TrackInfo> Tracks = new Dictionary<int, TrackInfo>();
+        public Dictionary<string, TrackInfo> TracksFnKeyed = new Dictionary<string, TrackInfo>();
         
         public event EventHandler Reloaded;
         public event EventHandler Updated;
@@ -132,6 +132,8 @@ namespace Banshee.Base
             
             is_loaded = true;
             
+            Banshee.Sources.SourceManager.AddSource(Banshee.Sources.LibrarySource.Instance, true);
+            
             ThreadAssist.ProxyToMain(delegate {
                 EventHandler handler = Reloaded;
                 if(handler != null) {
@@ -164,11 +166,11 @@ namespace Banshee.Base
         
         public void SetTrack(int id, LibraryTrackInfo track)
         {
-            lock(Tracks.SyncRoot) {
+            lock(((IDictionary)Tracks).SyncRoot) {
                 Tracks[id] = track;
             }
                 
-            lock(TracksFnKeyed.SyncRoot) {
+            lock(((IDictionary)TracksFnKeyed).SyncRoot) {
                 TracksFnKeyed[MakeFilenameKey(track.Uri)] = track;
             }
             
@@ -193,18 +195,18 @@ namespace Banshee.Base
         
         private void CollectionRemove(LibraryTrackInfo track)
         {
-            lock(Tracks.SyncRoot) {
+            lock(((IDictionary)Tracks).SyncRoot) {
                 Tracks.Remove(track.TrackId);
             }
             
-            lock(TracksFnKeyed.SyncRoot) {
+            lock(((IDictionary)TracksFnKeyed).SyncRoot) {
                 TracksFnKeyed.Remove(MakeFilenameKey(track.Uri));
             }
         }
 
-        /*private void Remove(Uri trackUri)
+        /*private void Remove(SafeUri trackSafeUri)
         {
-            Remove(TracksFnKeyed[MakeFilenameKey(trackUri)] as LibraryTrackInfo);
+            Remove(TracksFnKeyed[MakeFilenameKey(trackSafeUri)] as LibraryTrackInfo);
         }*/
         
         public void Remove(LibraryTrackInfo track)
@@ -240,8 +242,8 @@ namespace Banshee.Base
             foreach(object o in tracks) {
                 LibraryTrackInfo track = null;
                 
-                if(o is Uri) {
-                    track = TracksFnKeyed[MakeFilenameKey(o as Uri)] as LibraryTrackInfo;
+                if(o is SafeUri) {
+                    track = TracksFnKeyed[MakeFilenameKey(o as SafeUri)] as LibraryTrackInfo;
                 } else if(o is LibraryTrackInfo) {
                     track = o as LibraryTrackInfo;
                 } 
@@ -281,9 +283,9 @@ namespace Banshee.Base
             remove_queue.Add(track);
         }
         
-        public void QueueRemove(Uri trackUri)
+        public void QueueRemove(SafeUri trackSafeUri)
         {
-            remove_queue.Add(trackUri);
+            remove_queue.Add(trackSafeUri);
         }
         
         public void CommitRemoveQueue()
@@ -297,7 +299,7 @@ namespace Banshee.Base
             return Tracks[id] as LibraryTrackInfo;
         }
         
-        public static string MakeFilenameKey(Uri uri)
+        public static string MakeFilenameKey(SafeUri uri)
         {
             return PathUtil.MakeFileNameKey(uri);
         }
