@@ -1,4 +1,3 @@
-
 /***************************************************************************
  *  DatabaseRebuilder.cs
  *
@@ -32,7 +31,6 @@ using System.IO;
 using System.Collections;
 using Mono.Unix;
 using IPod;
-using Entagged;
 
 using Banshee.Base;
 using Banshee.Widgets;
@@ -74,7 +72,7 @@ namespace Banshee.Dap.Ipod
                 ScanMusicDirectory(directory);
             }
             
-            ProcessSongQueue();
+            ProcessTrackQueue();
         }
         
         private void ScanMusicDirectory(DirectoryInfo directory)
@@ -84,18 +82,18 @@ namespace Banshee.Dap.Ipod
             }
         }
         
-        private void ProcessSongQueue()
+        private void ProcessTrackQueue()
         {
             discovery_count = song_queue.Count;
             
-            user_event.Message = Catalog.GetString("Processing Songs...");
+            user_event.Message = Catalog.GetString("Processing Tracks...");
             
             while(song_queue.Count > 0) {
                 user_event.Progress = (double)(discovery_count - song_queue.Count) 
                     / (double)discovery_count;
                 
                 try {
-                    ProcessSong(song_queue.Dequeue() as FileInfo);
+                    ProcessTrack(song_queue.Dequeue() as FileInfo);
                 } catch {
                 }
                 
@@ -114,22 +112,22 @@ namespace Banshee.Dap.Ipod
             OnFinished();
         }
         
-        private void ProcessSong(FileInfo file)
+        private void ProcessTrack(FileInfo file)
         {
-            AudioFile af = new AudioFile(file.FullName);
-            Song song = dap.Device.SongDatabase.CreateSong();
+            TagLib.File af = TagLib.File.Create(file.FullName);
+            Track song = dap.Device.TrackDatabase.CreateTrack();
 
             song.FileName = file.FullName;
-            song.Album = af.Album;
-            song.Artist = af.Artist;
-            song.Title = af.Title;
-            song.Genre = af.Genre;
-            song.TrackNumber = af.TrackNumber;
-            song.TotalTracks = af.TrackCount;
-            song.Duration = af.Duration;
-            song.Year = af.Year;
-            song.BitRate = af.Bitrate / 1024;
-            song.SampleRate = (ushort)af.SampleRate;
+            song.Album = af.Tag.Album;
+            song.Artist = af.Tag.Artists[0];
+            song.Title = af.Tag.Title;
+            song.Genre = af.Tag.Genres[0];
+            song.TrackNumber = (int)af.Tag.Track;
+            song.TotalTracks = (int)af.Tag.TrackCount;
+            song.Duration = af.AudioProperties.Duration;
+            song.Year = (int)af.Tag.Year;
+            song.BitRate = af.AudioProperties.Bitrate / 1024;
+            song.SampleRate = (ushort)af.AudioProperties.SampleRate;
         }
         
         private void SaveDatabase()
@@ -139,7 +137,7 @@ namespace Banshee.Dap.Ipod
             user_event.Progress = 0.0;
             
             try {
-                dap.Device.SongDatabase.Save();
+                dap.Device.TrackDatabase.Save();
             } catch(Exception e) {
                 LogCore.Instance.PushError(
                     Catalog.GetString("Error rebuilding iPod database"),
