@@ -40,7 +40,7 @@ namespace Banshee.MediaEngine.Helix
 {    
     public class HelixRemotePlayerEngine : PlayerEngine, IEqualizer
     {
-        private RemotePlayer player;
+        private IRemotePlayer player;
         private uint timeout_id;
         private uint ping_id;
         
@@ -63,7 +63,7 @@ namespace Banshee.MediaEngine.Helix
         public override void Dispose()
         {
             base.Dispose();
-            player.Dispose();
+            player.Shutdown();
             player = null;
             GLib.Source.Remove(ping_id);
         }
@@ -102,17 +102,15 @@ namespace Banshee.MediaEngine.Helix
             player.Pause();
         }
         
-        public void OnRemotePlayerMessage(object o, MessageArgs args)
+        public void OnRemotePlayerMessage(MessageType messageType, IDictionary<string, object> args)
         {
-            Message message = args.Message;
-            
-            switch(message.Type) {
+            switch(messageType) {
                 case MessageType.ContentConcluded:
                     Close();
                     OnEventChanged(PlayerEngineEvent.EndOfStream);
                     break;
                 case MessageType.ContentState:
-                    switch((ContentState)message["NewState"]) {
+                    switch((ContentState)args["NewState"]) {
                         case ContentState.Paused:
                             OnStateChanged(PlayerEngineState.Paused);
                             break;
@@ -128,19 +126,19 @@ namespace Banshee.MediaEngine.Helix
                     }
                     break;
                 case MessageType.Buffering:
-                    uint progress = (uint)message["Percent"];
+                    uint progress = (uint)args["Percent"];
                     OnEventChanged(PlayerEngineEvent.Buffering, 
                         null, (double)progress / 100.0);
                     break;
                 case MessageType.Title:
-                    string title = message["Title"] as string;
+                    string title = args["Title"] as string;
                     if(title == null || title.Trim() == String.Empty) {
                         break;
                     }
                 
                     StreamTag tag = new StreamTag();
                     tag.Name = CommonTags.Title;
-                    tag.Value = (string)message["Title"];
+                    tag.Value = (string)args["Title"];
                     
                     OnTagFound(tag);
                     
@@ -149,15 +147,15 @@ namespace Banshee.MediaEngine.Helix
         }
          
         public override ushort Volume {
-            get { return (ushort)player.GetVolume(); }
+            get { return (ushort)player.Volume; }
             set {
-                player.SetVolume((uint)value);
+                player.Volume = (uint)value;
                 OnEventChanged(PlayerEngineEvent.Volume);
             }
         }
     
         public override uint Position {
-            get { return (uint)player.GetPosition() / 1000; }
+            get { return (uint)player.Position / 1000; }
             set {
                 if(player.StartSeeking()) {
                     if(player.SetPosition(value * 1000)) {
@@ -170,11 +168,11 @@ namespace Banshee.MediaEngine.Helix
         }
         
         public override uint Length { 
-            get { return (uint)player.GetLength() / 1000; }
+            get { return (uint)player.Length / 1000; }
         }        
         
         public override bool CanSeek {
-            get { return !player.GetIsLive(); }
+            get { return !player.IsLive; }
         }
         
         public override string Id {
@@ -211,8 +209,8 @@ namespace Banshee.MediaEngine.Helix
                 throw new ArgumentOutOfRangeException("value must be in range -100..100");
             }
             
-            if(player.GetIsEqualizerEnabled() == false) {
-                player.SetEqualizerEnabled(true);
+            if(!player.IsEqualizerEnabled) {
+                player.IsEqualizerEnabled = true;
             }
 
             if(frequency_map.Count == 0) {
