@@ -27,6 +27,7 @@
  */
  
 using System;
+using System.IO;
 using System.Collections;
 using Mono.Unix;
 using DAAP;
@@ -141,11 +142,12 @@ namespace Banshee.Plugins.Daap
         
         private static void OnServiceRemoved(object o, ServiceArgs args)
         {
-            Source source = source_map[args.Service.Name] as DaapSource;
+            DaapSource source = source_map[args.Service.Name] as DaapSource;
             if(source == null) {
                 return;
             }
-            
+
+            source.Disconnect (false);
             source.Dispose();
             SourceManager.RemoveSource(source);
             source_map.Remove(args.Service.Name);
@@ -192,6 +194,12 @@ namespace Banshee.Plugins.Daap
             song.TrackCount = (int)track.TrackCount;
             song.TrackNumber = (int)track.TrackNumber;
             song.Year = track.Year;
+
+            string ext = Path.GetExtension (song.FileName);
+            if (ext != null && ext.Length > 0) {
+                song.Format = Path.GetExtension (song.FileName).Substring (1);
+            }
+            
             return song;
         }
         
