@@ -1,4 +1,4 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
+
 /***************************************************************************
  *  ToggleState.cs
  *
@@ -38,6 +38,8 @@ namespace Banshee.Widgets
         private string label;
         private ToggleAction toggle_action;
         private bool check_active;
+        private bool match_active;
+        private bool match_value;
         
         protected ToggleState()
         {
@@ -82,5 +84,25 @@ namespace Banshee.Widgets
                 label = value;
             }
         }
+
+        public bool MatchActive {
+            get {
+                return match_active;
+            }
+
+            set {
+                match_active = value;
+            }
+        }
+
+        public bool MatchValue {
+            get {
+                return match_value;
+            }
+
+            set {
+                match_value = value;
+            }
+        }
     }
 }
