@@ -30,6 +30,7 @@ using System;
 using System.Diagnostics;
 using Gnome;
 using Mono.Unix;
+using NDesk.DBus;
 
 using Banshee.Base;
 
@@ -42,17 +43,19 @@ namespace Banshee
             Banshee.Gui.CleanRoomStartup.Startup(Startup, args);
         }
         
-        [System.Runtime.InteropServices.DllImport("libdbus-glib-1")]
-        private static extern void dbus_g_thread_init();
+        [System.Runtime.InteropServices.DllImport("libbanshee")]
+        private static extern void banshee_dbus_compat_thread_init();
         
         private static void Startup(string [] args)
         {
+            banshee_dbus_compat_thread_init();
+        
             try {
                 Utilities.SetProcessName("banshee");
             } catch {}
             
+            BusG.Init();
             Gtk.Application.Init();
-            dbus_g_thread_init();
         
             Globals.ArgumentQueue = new ArgumentQueue(new ArgumentLayout [] {
                 new ArgumentLayout("enqueue <files>","Files to enqueue, must be last argument specified"),
@@ -83,7 +86,7 @@ namespace Banshee
             }, args, "enqueue");
             
             HandleShallowCommands();
-            DBusPlayer dbus_core = DetectInstanceAndDbus();
+            IDBusPlayer dbus_core = DetectInstanceAndDbus();
             HandleDbusCommands(dbus_core);
             
             Globals.Initialize();
@@ -94,11 +97,11 @@ namespace Banshee
             Gtk.Application.Run();
         }
     
-        private static DBusPlayer DetectInstanceAndDbus()
+        private static IDBusPlayer DetectInstanceAndDbus()
         {
             try {
                 return DBusPlayer.FindInstance();
-            } catch {
+            } catch (Exception e) {
                 /*Process current_process = Process.GetCurrentProcess();
                 foreach(Process process in Process.GetProcesses()) {
                     if(process.ProcessName == current_process.ProcessName && process.Id != current_process.Id) {
@@ -110,11 +113,12 @@ namespace Banshee
                     }
                 }*/
 
+                Console.Error.WriteLine(e);
                 return null;
             }
         }
         
-        private static void HandleDbusCommands(DBusPlayer remote_player)
+        private static void HandleDbusCommands(IDBusPlayer remote_player)
         {
             if(remote_player == null) {
                 return;
@@ -245,13 +249,12 @@ namespace Banshee
             if(present) {
                 try {
                     Present(remote_player);
-                } catch(DBus.DBusException) {
+                } catch(Exception) {
+                    //FIXME: bad silent error handling
                     return;
                 }
             }
             
-            // Major nasty hack to work around dbus-sharp bug: bad IL in object Finalizer
-            System.GC.SuppressFinalize(remote_player);
             Gdk.Global.NotifyStartupComplete();
             System.Environment.Exit(0);
         }
@@ -265,7 +268,7 @@ namespace Banshee
             }
         }
         
-        private static void Present(DBusPlayer remote_player)
+        private static void Present(IDBusPlayer remote_player)
         {
             remote_player.PresentWindow();
         }
