@@ -28,7 +28,7 @@
 
 using System;
 using System.IO;
-using System.Data;
+//using System.Data;
 using System.Threading;
 using System.Reflection;
 using System.Collections;
@@ -611,6 +611,7 @@ namespace Banshee
       
         private bool OnShutdownRequested()
         {
+            WindowPlayer.Hide();
             ActiveUserEventsManager.Instance.CancelAll();
             playlistView.Shutdown();
             PlayerEngineCore.Dispose();
@@ -1083,6 +1084,7 @@ namespace Banshee
                 return;
             }
 
+            searchEntry.Ready = false;
             searchEntry.CancelSearch();
             
             if(source is DapSource) {
@@ -1112,6 +1114,8 @@ namespace Banshee
             UpdateSourceView();
                 
             OnPlaylistViewSelectionChanged(playlistView.Selection, new EventArgs());
+
+            searchEntry.Ready = true;
         }
         
         private void UpdateDapDiskUsageBar(DapSource dapSource)
@@ -1419,7 +1423,8 @@ namespace Banshee
             }
             
             TreePath path;
-            playlistView.GetPathAtPos((int)args.Event.X, (int)args.Event.Y, out path);
+            TreeViewColumn column;
+            playlistView.GetPathAtPos((int)args.Event.X, (int)args.Event.Y, out path, out column);
         
             if(path == null) {
                 return;
@@ -1442,6 +1447,24 @@ namespace Banshee
                 case EventType.ButtonPress:
                     if(playlistView.Selection.PathIsSelected(path) && (args.Event.State & 
                         (ModifierType.ControlMask | ModifierType.ShiftMask)) == 0) {
+                        if (column != null && args.Event.Button == 1 && column.CellRenderers.Length == 1) {
+                            CellRenderer renderer = column.CellRenderers[0];
+                            Gdk.Rectangle background_area = playlistView.GetBackgroundArea(path, column);
+                            Gdk.Rectangle cell_area = playlistView.GetCellArea(path, column);
+                            
+                            renderer.Activate(args.Event,
+                                              playlistView,
+                                              path.ToString(),
+                                              background_area,
+                                              cell_area,
+                                              CellRendererState.Selected);
+                            
+                            TreeIter iter;
+                            if (playlistModel.GetIter(out iter, path)) {
+                                playlistModel.EmitRowChanged(path, iter);
+                            }
+                        }
+                        
                         args.RetVal = true;
                     }
                     
@@ -1795,11 +1818,7 @@ namespace Banshee
 
         private void DeleteSong(TrackInfo ti)
         {
-            try {
-                File.Delete(ti.Uri.LocalPath);
-            } catch(Exception) {
-                Console.WriteLine("Could not delete file: " + ti.Uri.LocalPath);
-            }
+            File.Delete(ti.Uri.LocalPath);
 
             // trim empty parent directories
             try {
@@ -1872,17 +1891,30 @@ namespace Banshee
             foreach(TreePath path in playlistView.Selection.GetSelectedRows()) {
                 playlistModel.GetIter(out iters[i++], path);
             }
-            
+
             for(i = 0; i < iters.Length; i++) {
                 TrackInfo track = playlistModel.IterTrackInfo(iters[i]);
+
+                try {
+                    if(deleteFromFileSystem) {
+                        DeleteSong(track);
+                    }
+                } catch (UnauthorizedAccessException e) {
+                    string header = Catalog.GetString ("Delete songs from drive");
+                    string msg = String.Format (Catalog.GetString ("You do not have the required permissions to delete '{0}'"), track.Uri.LocalPath);
+                    HigMessageDialog error = new HigMessageDialog (WindowPlayer,
+                                                                   DialogFlags.DestroyWithParent, MessageType.Error,
+                                                                   ButtonsType.Close,
+                                                                   header, msg);
+                    error.Run ();
+                    error.Destroy ();
+                    break;
+                }
+                
                 SourceManager.ActiveSource.RemoveTrack(track);
                 playlistModel.RemoveTrack(ref iters[i], track);
-                
-                if(deleteFromFileSystem) {
-                    DeleteSong(track);
-                }
             }
-            
+                
             SourceManager.ActiveSource.Commit();
             sourceView.QueueDraw();
             playlistView.QueueDraw();
