@@ -43,7 +43,7 @@ namespace Banshee
         Single
     }
 
-    public class PlaylistModel : ListStore, IPlaybackModel
+    public class PlaylistModel : ListStore
     {
         private static int uid;
         private TimeSpan totalDuration = new TimeSpan(0);
@@ -57,7 +57,9 @@ namespace Banshee
         
         public event EventHandler Updated;
         public event EventHandler Stopped;
-        
+
+        private uint timeout_id = 0;
+
         public static int NextUid
         {
             get {
@@ -68,28 +70,30 @@ namespace Banshee
         public PlaylistModel() : base(typeof(TrackInfo))
         {
             trackInfoQueue = new ArrayList();
-            GLib.Timeout.Add(300, new GLib.TimeoutHandler(OnIdle));
             SourceManager.ActiveSourceChanged += delegate(SourceEventArgs args) {
                 ReloadSource();
             };
         }
-    
+
         // --- Load Queue and Additions ---
         private bool OnIdle()
         {
+            timeout_id = 0;
             QueueSync();
-            return true;
+            return false;
         }
 
         private void QueueSync()
         {
-            if(trackInfoQueue.Count <= 0)
+            if(trackInfoQueue.Count <= 0) {
                 return;
+            }
             
             trackInfoQueueLocked = true;
                 
             foreach(TrackInfo ti in trackInfoQueue)
-                AddTrack(ti);
+                AddTrack(ti, false);
+            RaiseUpdated(this, new EventArgs());
 
             trackInfoQueue.Clear();
             trackInfoQueueLocked = false;
@@ -102,6 +106,9 @@ namespace Banshee
         {
             while(trackInfoQueueLocked);
             trackInfoQueue.Add(ti);
+            if (timeout_id == 0) {
+                timeout_id = GLib.Timeout.Add(300, new GLib.TimeoutHandler(OnIdle));
+            }
         }
 
         private void OnLoaderHaveTrackInfo(object o, HaveTrackInfoArgs args)
@@ -134,8 +141,9 @@ namespace Banshee
             
             lock(SourceManager.ActiveSource.TracksMutex) {
                 foreach(TrackInfo track in SourceManager.ActiveSource.Tracks) {
-                    AddTrack(track);
+                    AddTrack(track, false);
                 }
+                RaiseUpdated(this, new EventArgs());
             }
         }
 
